Stan Math Library: stan/math/prim/mat/prob/dirichlet_log.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
dirichlet_log.hpp File Reference
`#include <boost/math/special_functions/gamma.hpp>`
`#include <boost/random/gamma_distribution.hpp>`
`#include <boost/random/variate_generator.hpp>`
`#include <stan/math/prim/mat/err/check_simplex.hpp>`
`#include <stan/math/prim/scal/err/check_consistent_sizes.hpp>`
`#include <stan/math/prim/scal/err/check_positive.hpp>`
`#include <stan/math/prim/scal/fun/multiply_log.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <stan/math/prim/scal/meta/include_summand.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<bool propto, typename T_prob , typename T_prior_sample_size >
boost::math::tools::promote_args< T_prob, T_prior_sample_size >::type | stan::math::dirichlet_log (const Eigen::Matrix< T_prob, Eigen::Dynamic, 1 > &theta, const Eigen::Matrix< T_prior_sample_size, Eigen::Dynamic, 1 > &alpha)
| The log of the Dirichlet density for the given theta and a vector of prior sample sizes, alpha. More...
template<typename T_prob , typename T_prior_sample_size >
boost::math::tools::promote_args< T_prob, T_prior_sample_size >::type | stan::math::dirichlet_log (const Eigen::Matrix< T_prob, Eigen::Dynamic, 1 > &theta, const Eigen::Matrix< T_prior_sample_size, Eigen::Dynamic, 1 > &alpha)

[ Stan Home Page ] © 2011–2016, Stan Development Team.